@@ -20,7 +20,7 @@ import           Data.Traversable     as Import
 import           Data.Void            as Import (Void)
 import           Text.Blaze           as Import (Markup)
 
-import           Hledger.Web.Foundation           as Import
+import           Hledger.Web.App                  as Import
 import           Hledger.Web.Settings             as Import
 import           Hledger.Web.Settings.StaticFiles as Import
-import           Hledger.Web.WebOptions           as Import (Capability(..))
+import           Hledger.Web.WebOptions           as Import (Permission(..))
